@@ -512,6 +512,9 @@ def setup_common_resource(app):
 
         # 获取请求头并删除不必要的字段（如 Host）
         headers = {key: value for key, value in request.headers if key.lower() in ["authorization"]}
+
+        # 添加到 headers
+        headers["remote-addr"] = request.remote_addr
         files = []
         response = requests.request("POST", app_config.get("CAPABILITY_PLATFORM_SERVER") + "/icp/oauth/token",
                                     headers=headers,
